pygeai.tests.snippets.lab.use\_cases package
============================================

Submodules
----------

pygeai.tests.snippets.lab.use\_cases.c\_code\_fixer\_agent\_flow module
-----------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.c_code_fixer_agent_flow
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.create\_cli\_expert module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.create_cli_expert
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.create\_lab\_expert module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.create_lab_expert
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.create\_tool\_headless\_web\_browser module
--------------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.create_tool_headless_web_browser
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.create\_web\_designer module
-----------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.create_web_designer
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.create\_web\_reader module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.create_web_reader
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.file\_summarizer\_example module
---------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.file_summarizer_example
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.file\_summarizer\_example\_2 module
------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.file_summarizer_example_2
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.update\_cli\_expert module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.update_cli_expert
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.update\_lab\_expert module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.update_lab_expert
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.update\_web\_designer module
-----------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.update_web_designer
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.update\_web\_reader module
---------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.update_web_reader
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.use\_cases.update\_web\_reader\_with\_tool module
---------------------------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.use_cases.update_web_reader_with_tool
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.lab.use_cases
   :members:
   :show-inheritance:
   :undoc-members:
